@@ -1,7 +1,7 @@
 ### SHELL> mpiexec -np 4 Rscript --vanilla [...].r
 
 ### Initial MPI.
-library(pbdDEMO, quiet = TRUE)
+library(pbdDEMO, quietly = TRUE)
 init.grid()
 if(comm.size() != 4){
   stop("This example requries 4 processors.")
