@@ -7,7 +7,7 @@ pdflatex pbdDEMO-guide.Rnw
 makeindex pbdDEMO-guide.idx
 pdflatex pbdDEMO-guide.Rnw
 pdflatex pbdDEMO-guide.Rnw
-Rscript -e "tools::compactPDF('.', gs_quality='ebook')"
+Rscript -e "tools::compactPDF('pbdDEMO-guide.pdf', gs_quality='ebook')"
 rm *.aux *.bbl *.blg *.log *.out *.toc *.idx *.lof *.lot *.ind *.ilg
 
 # Rscript -e "tools::compactPDF('./pbdDEMO-guide.pdf',gs_quality='ebook')"
